<?xml version="1.0" encoding="UTF-8"?>

<!--
 @file docgen.nls.xsl
 
 This stylesheet is responsible for doing NLS conversions on text.
 A template is provided to do the conversions.
 All the NLS text is then pre-loaded into global variables.
 This stylesheet is included by both the toc and main stylesheets.
-->

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsd="http://www.w3.org/2001/XMLSchema"
  xmlns:xalan="http://xml.apache.org/xslt">
  
  <!-- Used by template lookupText for resolving NLS text -->
  <xsl:key name="lookupText" match="kvpair" use="@key"/>
  
  <!-- Including stylesheets will define the variable nlsfile -->

  <!--
 #        ####    ####   #    #  #    #  #####    #####  ######  #    #   #####
 #       #    #  #    #  #   #   #    #  #    #     #    #        #  #      #
 #       #    #  #    #  ####    #    #  #    #     #    #####     ##       #
 #       #    #  #    #  #  #    #    #  #####      #    #         ##       #
 #       #    #  #    #  #   #   #    #  #          #    #        #  #      #
 ######   ####    ####   #    #   ####   #          #    ######  #    #     #

	 NLS translation template.  
	 Any NLS text is stored in a secondary XML document
	 The format of the secandary document is
	   <text>
       <kvpair key="key1" value="NLSval1"/>
       <kvpair key="key2" value="NLSva12"/>
     </text>
  -->
  <xsl:template name="lookupText">
    <xsl:param name="key" select="NoKeySupplied"/>
    <xsl:for-each select="document($nlsfile)/text">
      <xsl:choose>
        <xsl:when test="key('lookupText',$key)/@value">
          <xsl:value-of select="key('lookupText',$key)/@value"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat('Key ', $key,' not found.')"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:template>

	<!-- Preload NLS text into global variables -->
	<!--
	<xsl:variable name="String">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="''" />
		</xsl:call-template>
	</xsl:variable>
	-->
	<xsl:variable name="abstractString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'abstract'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="allString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'all'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="anonymousString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'anonymous'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="atomicString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'atomic'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="basetypeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'basetype'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="blockString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'block'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="choiceString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'choice'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="contentmodelString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'contentmodel'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="defaultString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'default'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="defaultBlockString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'defaultBlock'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="defaultFinalString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'defaultFinal'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="derivedbyString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'derivedby'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="documentationString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'documentation'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="emptyString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'empty'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="enumerationString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'enumeration'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="exclusivemaxString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'exclusivemax'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="exclusiveminString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'exclusivemin'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="extensionString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'extension'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="falseString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'false'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="finalString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'final'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="fixedString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'fixed'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="fractiondigitsString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'fractiondigits'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="fullnameString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'fullname'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="localgroupString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'localgroup'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="groupreferenceString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'groupreference'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="groupcontentString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'groupcontent'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="inclusivemaxString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'inclusivemax'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="inclusiveminString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'inclusivemin'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="itemtypeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'itemtype'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="lengthString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'length'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="localSimpleTypeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'localsimpletype'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="localComplexTypeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'localcomplextype'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="listString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'list'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="maxString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'max'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="maxoccursString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'maxoccurs'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="membertypeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'membertype'" />
		</xsl:call-template>
	</xsl:variable>
    <xsl:variable name="messagesetString">
        <xsl:call-template name="lookupText">
            <xsl:with-param name="key" select="'messageset'" />
        </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="messagealiasString">
        <xsl:call-template name="lookupText">
            <xsl:with-param name="key" select="'messagealias'" />
        </xsl:call-template>
    </xsl:variable>
	<xsl:variable name="minString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'min'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="minoccursString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'minoccurs'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="mixedString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'mixed'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nameString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'name'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="namespaceString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'namespace'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="namespaceAttributeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'namespaceAttribute'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="namespaceElementString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'namespaceElement'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="namespacePrefixString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'namespacePrefix'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="namespaceTargetString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'namespaceTarget'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nillableString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'nillable'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="noneString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'none'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="noTargetNamespaceString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'noTargetNamespace'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="optionalString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'optional'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="orderedSetString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'orderedSet'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="patternString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'pattern'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="processcontentsString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'processcontents'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="prohibitedString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'prohibited'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="recursionIndicatorString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'recursionIndicator'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="referencenameString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'referencename'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="requiredString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'required'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="restrictionString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'restriction'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="sequenceString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'sequence'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="substitutiongroupString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'substitutiongroup'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="totaldigitsString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'totaldigits'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="trueString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'true'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="typeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'type'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="typecontentString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'typecontent'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="unionString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'union'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="unnamedString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'unnamed'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="unorderedSetString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'unorderedSet'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="usageString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'usage'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="varietyString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'variety'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="whitespaceString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'whitespace'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="wildcardAttributeString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'wildcardAttribute'" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="wildcardElementString">
		<xsl:call-template name="lookupText">
			<xsl:with-param name="key" select="'wildcardElement'" />
		</xsl:call-template>
	</xsl:variable>

</xsl:stylesheet>